@@ -1,8 +1,14 @@
-from typing import Literal, Optional
+from typing import Optional
+try:
+    from typing import Literal
+except:
+    from typing_extensions import Literal
+
 from beartype import beartype
+
 from pglet.control import Control
 
-BOX_SIDE = Literal[None, "start", "end"]
+BoxSide = Literal[None, "start", "end"]
 
 
 class Checkbox(Control):
@@ -12,7 +18,8 @@ class Checkbox(Control):
         id=None,
         value=None,
         value_field=None,
-        box_side: BOX_SIDE = None,
+        box_side: BoxSide = None,
+        focused=None,
         data=None,
         width=None,
         height=None,
@@ -37,6 +44,7 @@ class Checkbox(Control):
         self.value_field = value_field
         self.label = label
         self.box_side = box_side
+        self.focused = focused
         self.on_change = on_change
 
     def _get_control_name(self):
@@ -87,5 +95,15 @@ class Checkbox(Control):
 
     @box_side.setter
     @beartype
-    def box_side(self, value: BOX_SIDE):
+    def box_side(self, value: BoxSide):
         self._set_attr("boxSide", value)
+
+    # focused
+    @property
+    def focused(self):
+        return self._get_attr("focused")
+
+    @focused.setter
+    @beartype
+    def focused(self, value: Optional[bool]):
+        self._set_attr("focused", value)
