@@ -1,3 +1,7 @@
+from typing import Optional
+
+from beartype import beartype
+
 from pglet.control import Control
 
 
@@ -13,7 +17,10 @@ class ChoiceGroup(Control):
         height=None,
         padding=None,
         margin=None,
+        focused=None,
         on_change=None,
+        on_focus=None,
+        on_blur=None,
         visible=None,
         disabled=None,
     ):
@@ -30,7 +37,10 @@ class ChoiceGroup(Control):
         )
         self.value = value
         self.label = label
+        self.focused = focused
         self.on_change = on_change
+        self.on_focus = on_focus
+        self.on_blur = on_blur
         self.__options = []
         if options != None:
             for option in options:
@@ -78,6 +88,34 @@ class ChoiceGroup(Control):
     def _get_children(self):
         return self.__options
 
+    # focused
+    @property
+    def focused(self):
+        return self._get_attr("focused")
+
+    @focused.setter
+    @beartype
+    def focused(self, value: Optional[bool]):
+        self._set_attr("focused", value)
+
+    # on_focus
+    @property
+    def on_focus(self):
+        return self._get_event_handler("focus")
+
+    @on_focus.setter
+    def on_focus(self, handler):
+        self._add_event_handler("focus", handler)
+
+    # on_blur
+    @property
+    def on_blur(self):
+        return self._get_event_handler("blur")
+
+    @on_blur.setter
+    def on_blur(self, handler):
+        self._add_event_handler("blur", handler)
+
 
 class Option(Control):
     def __init__(self, key=None, text=None, icon=None, icon_color=None):
