@@ -1,11 +1,38 @@
 import datetime as dt
 import threading
 from typing import Optional
-from beartype import beartype
 from difflib import SequenceMatcher
 
+try:
+    from typing import Literal
+except:
+    from typing_extensions import Literal
+
+from beartype import beartype
+
 from pglet.protocol import Command
 
+BorderStyle = Literal[
+    None, "dotted", "dashed", "solid", "double", "groove", "ridge", "inset", "outset"
+]
+
+TextSize = Literal[
+    None,
+    "tiny",
+    "xSmall",
+    "small",
+    "smallPlus",
+    "medium",
+    "mediumPlus",
+    "large",
+    "xLarge",
+    "xxLarge",
+    "superLarge",
+    "mega",
+]
+
+TextAlign = Literal[None, "left", "right", "center", "justify"]
+
 
 class Control:
     def __init__(
