@@ -1,5 +1,15 @@
+from typing import Optional
+try:
+    from typing import Literal
+except:
+    from typing_extensions import Literal
+
+from beartype import beartype
+
 from pglet.control import Control
 
+ItemType = Literal[None, "normal", "divider", "header"]
+
 
 class Dropdown(Control):
     def __init__(
@@ -10,6 +20,8 @@ class Dropdown(Control):
         placeholder=None,
         error_message=None,
         on_change=None,
+        on_focus=None,
+        on_blur=None,
         options=None,
         width=None,
         height=None,
@@ -17,6 +29,7 @@ class Dropdown(Control):
         margin=None,
         visible=None,
         disabled=None,
+        focused=None,
         data=None,
     ):
         Control.__init__(
@@ -34,7 +47,10 @@ class Dropdown(Control):
         self.value = value
         self.placeholder = placeholder
         self.error_message = error_message
+        self.focused = focused
         self.on_change = on_change
+        self.on_focus = on_focus
+        self.on_blur = on_blur
         self.__options = []
         if options != None:
             for option in options:
@@ -100,13 +116,43 @@ class Dropdown(Control):
     def _get_children(self):
         return self.__options
 
+    # focused
+    @property
+    def focused(self):
+        return self._get_attr("focused")
+
+    @focused.setter
+    @beartype
+    def focused(self, value: Optional[bool]):
+        self._set_attr("focused", value)
+
+    # on_focus
+    @property
+    def on_focus(self):
+        return self._get_event_handler("focus")
+
+    @on_focus.setter
+    def on_focus(self, handler):
+        self._add_event_handler("focus", handler)
+
+    # on_blur
+    @property
+    def on_blur(self):
+        return self._get_event_handler("blur")
+
+    @on_blur.setter
+    def on_blur(self, handler):
+        self._add_event_handler("blur", handler)
+
 
 class Option(Control):
-    def __init__(self, key=None, text=None):
+    def __init__(self, key=None, text=None, item_type: ItemType = None, disabled=None):
         Control.__init__(self)
         assert key != None or text != None, "key or text must be specified"
         self.key = key
         self.text = text
+        self.item_type = item_type
+        self.disabled = disabled
 
     def _get_control_name(self):
         return "option"
@@ -128,3 +174,23 @@ class Option(Control):
     @text.setter
     def text(self, value):
         self._set_attr("text", value)
+
+    # item_type
+    @property
+    def item_type(self):
+        return self._get_attr("itemtype")
+
+    @item_type.setter
+    @beartype
+    def item_type(self, value: ItemType):
+        self._set_attr("itemtype", value)
+
+    # disabled
+    @property
+    def disabled(self):
+        return self._get_attr("disabled")
+
+    @disabled.setter
+    @beartype
+    def disabled(self, value: Optional[bool]):
+        self._set_attr("disabled", value)
