@@ -1,26 +1,14 @@
-from typing import Literal, Optional
-from beartype import beartype
-from pglet.control import Control
+from typing import Optional
+try:
+    from typing import Literal
+except:
+    from typing_extensions import Literal
 
-HORIZONTAL_ALIGN = Literal[None, "left", "center", "right", "justify"]
-VERTICAL_ALIGN = Literal[None, "top", "center", "bottom"]
-SIZE = Literal[
-    None,
-    "tiny",
-    "xSmall",
-    "small",
-    "smallPlus",
-    "medium",
-    "mediumPlus",
-    "large",
-    "xLarge",
-    "xxLarge",
-    "superLarge",
-    "mega",
-]
-BORDER_STYLE = Literal[
-    None, "dotted", "dashed", "solid", "double", "groove", "ridge", "inset", "outset"
-]
+from beartype import beartype
+
+from pglet.control import Control, BorderStyle, TextSize, TextAlign
+
+VerticalAlign = Literal[None, "top", "center", "bottom"]
 
 
 class Text(Control):
@@ -29,9 +17,9 @@ class Text(Control):
         value=None,
         id=None,
         markdown=None,
-        align: HORIZONTAL_ALIGN = None,
-        vertical_align: VERTICAL_ALIGN = None,
-        size: SIZE = None,
+        align: TextAlign = None,
+        vertical_align: VerticalAlign = None,
+        size: TextSize = None,
         bold=None,
         italic=None,
         pre=None,
@@ -39,15 +27,10 @@ class Text(Control):
         block=None,
         color=None,
         bgcolor=None,
-        border=None,
-        border_style: BORDER_STYLE = None,
+        border_style: BorderStyle = None,
         border_width=None,
         border_color=None,
         border_radius=None,
-        border_left=None,
-        border_right=None,
-        border_top=None,
-        border_bottom=None,
         width=None,
         height=None,
         padding=None,
@@ -79,15 +62,10 @@ class Text(Control):
         self.block = block
         self.color = color
         self.bgcolor = bgcolor
-        self.border = border
         self.border_style = border_style
         self.border_width = border_width
         self.border_color = border_color
         self.border_radius = border_radius
-        self.border_left = border_left
-        self.border_right = border_right
-        self.border_top = border_top
-        self.border_bottom = border_bottom
 
     def _get_control_name(self):
         return "text"
@@ -118,7 +96,7 @@ class Text(Control):
 
     @align.setter
     @beartype
-    def align(self, value: HORIZONTAL_ALIGN):
+    def align(self, value: TextAlign):
         self._set_attr("align", value)
 
     # vertical_align
@@ -128,7 +106,7 @@ class Text(Control):
 
     @vertical_align.setter
     @beartype
-    def vertical_align(self, value: VERTICAL_ALIGN):
+    def vertical_align(self, value: VerticalAlign):
         self._set_attr("verticalAlign", value)
 
     # size
@@ -138,7 +116,7 @@ class Text(Control):
 
     @size.setter
     @beartype
-    def size(self, value: SIZE):
+    def size(self, value: TextSize):
         self._set_attr("size", value)
 
     # bold
@@ -209,15 +187,6 @@ class Text(Control):
     def bgcolor(self, value):
         self._set_attr("bgcolor", value)
 
-    # border
-    @property
-    def border(self):
-        return self._get_attr("border")
-
-    @border.setter
-    def border(self, value):
-        self._set_attr("border", value)
-
     # border_style
     @property
     def border_style(self):
@@ -225,7 +194,7 @@ class Text(Control):
 
     @border_style.setter
     @beartype
-    def border_style(self, value: BORDER_STYLE):
+    def border_style(self, value: BorderStyle):
         self._set_attr("borderStyle", value)
 
     # border_width
@@ -254,39 +223,3 @@ class Text(Control):
     @border_radius.setter
     def border_radius(self, value):
         self._set_attr("borderRadius", value)
-
-    # border_left
-    @property
-    def border_left(self):
-        return self._get_attr("borderLeft")
-
-    @border_left.setter
-    def border_left(self, value):
-        self._set_attr("borderLeft", value)
-
-    # border_right
-    @property
-    def border_right(self):
-        return self._get_attr("borderRight")
-
-    @border_right.setter
-    def border_right(self, value):
-        self._set_attr("borderRight", value)
-
-    # border_top
-    @property
-    def border_top(self):
-        return self._get_attr("borderTop")
-
-    @border_top.setter
-    def border_top(self, value):
-        self._set_attr("borderTop", value)
-
-    # border_bottom
-    @property
-    def border_bottom(self):
-        return self._get_attr("borderBottom")
-
-    @border_bottom.setter
-    def border_bottom(self, value):
-        self._set_attr("borderBottom", value)
