@@ -1,8 +1,8 @@
-from typing import Optional, Literal
-from beartype import beartype
-from pglet.control import Control
+from typing import Optional
 
-ALIGN = Literal[None, "left", "right", "center", "justify"]
+from beartype import beartype
+
+from pglet.control import TextAlign, Control
 
 
 class Textbox(Control):
@@ -25,12 +25,15 @@ class Textbox(Control):
         auto_adjust_height=None,
         underlined=None,
         borderless=None,
+        focused=None,
         on_change=None,
+        on_focus=None,
+        on_blur=None,
         width=None,
         height=None,
         padding=None,
         margin=None,
-        align: ALIGN = None,
+        align: TextAlign = None,
         visible=None,
         disabled=None,
     ):
@@ -61,7 +64,10 @@ class Textbox(Control):
         self.borderless = borderless
         self.password = password
         self.required = required
+        self.focused = focused
         self.on_change = on_change
+        self.on_focus = on_focus
+        self.on_blur = on_blur
 
     def _get_control_name(self):
         return "textbox"
@@ -154,7 +160,7 @@ class Textbox(Control):
 
     @align.setter
     @beartype
-    def align(self, value: ALIGN):
+    def align(self, value: TextAlign):
         self._set_attr("align", value)
 
     # multiline
@@ -227,6 +233,16 @@ class Textbox(Control):
     def required(self, value: Optional[bool]):
         self._set_attr("required", value)
 
+    # focused
+    @property
+    def focused(self):
+        return self._get_attr("focused")
+
+    @focused.setter
+    @beartype
+    def focused(self, value: Optional[bool]):
+        self._set_attr("focused", value)
+
     # on_change
     @property
     def on_change(self):
@@ -239,3 +255,21 @@ class Textbox(Control):
             self._set_attr("onchange", True)
         else:
             self._set_attr("onchange", None)
+
+    # on_focus
+    @property
+    def on_focus(self):
+        return self._get_event_handler("focus")
+
+    @on_focus.setter
+    def on_focus(self, handler):
+        self._add_event_handler("focus", handler)
+
+    # on_blur
+    @property
+    def on_blur(self):
+        return self._get_event_handler("blur")
+
+    @on_blur.setter
+    def on_blur(self, handler):
+        self._add_event_handler("blur", handler)
